---
name: Bug Report
about: '"Something''s wrong..."'
title: ''
labels: bug
assignees: ''

---

This text document allows the plugin developers to gather the information they need to understand and prioritize your bug report. Please write your responses in the space below each section (replace [your answer here] with your answer), then click the "Submit new issue" button when you are finished. You can preview the formatting of this document using the Preview tab above.

## Description
*A clear description of the bug*
[your answer here]

### Error message
```
[Paste your napari error output here, if any.]
* If you can't find the error message, go to Plugins > Plugin Errors > napari-allencell-segmenter
* Most of the time, the most helpful information is at the very bottom of the error output
```

## Expected Behavior
*What did you expect to happen instead?*
[your answer here]

## Reproduction
*Please list the exact steps we can take to reproduce this bug.*
1. [first step]
2. [second step]
3. [so on...]

## Environment
- Operating system (ex. MacOS Big Sur): [your answer here]
- Python version (ex. 3.8): [your answer here]
- napari version (ex. 0.4.1): [your answer here, you can find it by going to help -> napari info in napari]
- How did you install the napari viewer (as a bundled app or through command line with `pip`)?: [your answer here]
